
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.012.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Provides configurable filtering of data that is logged to the debug logs (and error screen)",
  "dist_author" => [
    "Brian Phillips <bphillips\@cpan.org>"
  ],
  "dist_name" => "CatalystX-DebugFilter",
  "dist_version" => "0.16",
  "license" => "perl",
  "module_name" => "CatalystX::DebugFilter",
  "recursive_test_files" => 1,
  "requires" => {
    "Moose::Role" => 0,
    "Scalar::Util" => 0,
    "namespace::autoclean" => 0,
    "perl" => "5.008"
  },
  "test_requires" => {
    "Catalyst" => 0,
    "Catalyst::Controller" => 0,
    "Catalyst::Log" => 0,
    "Catalyst::ScriptRunner" => 0,
    "Catalyst::Test" => 0,
    "FindBin" => 0,
    "HTTP::Request::Common" => 0,
    "Moose" => 0,
    "Test::More" => 0,
    "Test::Pod" => "1.14",
    "Test::Pod::Coverage" => "1.04",
    "Test::WWW::Mechanize::Catalyst" => 0,
    "lib" => 0,
    "ok" => 0,
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "Catalyst" => 0,
  "Catalyst::Controller" => 0,
  "Catalyst::Log" => 0,
  "Catalyst::ScriptRunner" => 0,
  "Catalyst::Test" => 0,
  "FindBin" => 0,
  "HTTP::Request::Common" => 0,
  "Module::Build" => "0.28",
  "Moose" => 0,
  "Test::More" => 0,
  "Test::Pod" => "1.14",
  "Test::Pod::Coverage" => "1.04",
  "Test::WWW::Mechanize::Catalyst" => 0,
  "lib" => 0,
  "ok" => 0,
  "strict" => 0,
  "warnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
